@@ -70,7 +70,7 @@ class ModelIsotherm(BaseIsotherm):
         Unit of pressure, if applicable.
     loading_basis : str, optional
         Whether the adsorbed amount is in terms of either 'volume_gas'
-        'volume_liquid', 'molar', 'mass', or a fractional/percent basis.
+        'volume_liquid', 'molar', 'mass', or a fraction/percent basis.
     loading_unit : str, optional
         Unit in which the loading basis is expressed.
     material_basis : str, optional
