@@ -49,11 +49,11 @@ class Freundlich(IsothermBaseModel):
     name = 'Freundlich'
     formula = r"n(p) = K p^{ 1/m }"
     calculates = 'loading'
-    param_names = ["K", "m"]
-    param_bounds = {
-        "K": [0, numpy.inf],
-        "m": [0, numpy.inf],
-    }
+    param_names = ("K", "m")
+    param_default_bounds = (
+        (0, numpy.inf),
+        (0, numpy.inf),
+    )
 
     def loading(self, pressure):
         """
@@ -121,7 +121,9 @@ class Freundlich(IsothermBaseModel):
         float
             Spreading pressure at specified pressure.
         """
-        return self.params["m"] * self.params["K"] * pressure**(1 / self.params["m"])
+        K = self.params["K"]
+        m = self.params["m"]
+        return m * K * pressure**(1 / m)
 
     def initial_guess(self, pressure, loading):
         """
@@ -140,13 +142,6 @@ class Freundlich(IsothermBaseModel):
             Dictionary of initial guesses for the parameters.
         """
         saturation_loading, langmuir_k = super().initial_guess(pressure, loading)
-
         guess = {"K": saturation_loading * langmuir_k, "m": 1}
-
-        for param in guess:
-            if guess[param] < self.param_bounds[param][0]:
-                guess[param] = self.param_bounds[param][0]
-            if guess[param] > self.param_bounds[param][1]:
-                guess[param] = self.param_bounds[param][1]
-
+        guess = self.initial_guess_bounds(guess)
         return guess
