@@ -218,7 +218,12 @@ def isotherm_from_xl(path, *isotherm_parameters):
 
     # read the main isotherm parameters
     for field in _META_DICT.values():
-        raw_dict[field['name']] = sht.cell(field['row'], field['column'] + 1).value
+        valc = sht.cell(field['row'], field['column'] + 1)
+        if valc.ctype == xlrd.XL_CELL_EMPTY:
+            val = None
+        else:
+            val = valc.value
+        raw_dict[field['name']] = val
 
     # find data/model limits
     type_row = _META_DICT['isotherm_data']['row']
@@ -251,7 +256,7 @@ def isotherm_from_xl(path, *isotherm_parameters):
                 sht.cell(i, header_col).value for i in range(start_row, final_row)
             ]
             header_col += 1
-        data = pandas.DataFrame(experiment_data)
+        data = pandas.DataFrame(experiment_data).convert_dtypes()
 
         raw_dict['pressure_key'] = headers[0]
         raw_dict['loading_key'] = headers[1]
